---
name: Feature Request
about: Describe the feature you'd like implemented
title: "[REQUEST]"
labels: enhancement
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
<!--
A clear and concise description of what the problem is. Ex. I am working on [...] and
I would like [...] or I have trouble with [...]
-->

**Is there a specific integral/formula that you would like implemented?**
<!--
A clear and concise formula goes a long way. Have a look at the documentation and using the
conventions defined, and write out the explicit formula without domain-specific or short-hand
notations. You can submit it as a latex equation or as a picture.

References to academic papers help, but they're often not the easiest to work with. We can use the
formula you post here for the documentation.
-->

**Is there a change to the code or algorithm you would like to see?**
<!-- A clear and concise description of the proposed change and its reasoning. -->

**Additional context**
<!-- Add any other context or screenshots about the feature request here. -->
